==> ui-react-1.0.84.tgz: package/esm/NavigationBar/NavigationBar.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["color", "tonal", "version", "value", "valueDefault", "onChange", "fixed", "className", "style", "children"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
import React from 'react';
import { is } from '@onesy/utils';
import { classNames, style as styleMethod, useOnesyTheme } from '@onesy/style-react';
import LineElement from '../Line';
import SurfaceElement from '../Surface';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {
    zIndex: theme.z_index.app_bar,
    width: '100%',
    padding: '0'
  },
  fixed: {
    position: 'fixed',
    insetInline: '0',
    bottom: '0'
  }
}), {
  name: 'onesy-NavigationBar'
});
const NavigationBar = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useOnesyTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.onesyNavigationBar?.props?.default), props_), [props_]);
  const Line = React.useMemo(() => theme?.elements?.Line || LineElement, [theme]);
  const Surface = React.useMemo(() => theme?.elements?.Surface || SurfaceElement, [theme]);
  const {
      color = 'primary',
      tonal = true,
      version = 'regular',
      value,
      valueDefault,
      onChange,
      fixed,
      className,
      style,
      children: children_
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const [init, setInit] = React.useState(false);
  const [selected, setSelected] = React.useState(() => {
    const valueNew = valueDefault !== undefined ? valueDefault : value;
    return valueNew !== undefined ? is('array', valueNew) ? valueNew : [valueNew] : [];
  });
  const styles = {
    root: {},
    icon: {}
  };
  React.useEffect(() => {
    setInit(true);
  }, []);
  React.useEffect(() => {
    if (init && value !== selected) setSelected(is('array', value) ? value : [value]);
  }, [value]);
  const onSelect = itemProps => {
    // Only one item at the time is selectable,
    // and it cannot be unselected by clicking on the same item
    const valueNew = [itemProps.value];
    if (valueNew !== undefined) {
      // Update inner or controlled
      if (!props.hasOwnProperty('value')) setSelected(valueNew);
      if (is('function', onChange)) onChange(valueNew);
    }
  };
  let palette;
  if (!theme.palette.color[color] && !['themed', 'inverted', 'default', 'inherit'].includes(color)) {
    palette = theme.methods.color(color);
  }
  if (!theme.palette.color[color] && !['themed', 'inverted', 'default', 'inherit'].includes(color)) {
    if (tonal) styles.root.backgroundColor = theme.methods.palette.color.value(undefined, 95, true, palette);else styles.root.backgroundColor = palette.main;
  }
  if (!tonal) {
    let background = theme.palette.color[color]?.main;
    if (color === 'default') background = theme.palette.background.default.primary;
    styles.icon.color = theme.methods.palette.color.text(palette?.main || background, true, 'light');
  } else {
    styles.icon.color = theme.methods.palette.color.value(color, 5, true, palette);
  }
  const children = React.Children.toArray(children_).map((item, index) => /*#__PURE__*/React.cloneElement(item, _objectSpread(_objectSpread({
    key: index
  }, ['onesy-NavigationItem'].includes(item.type?.displayName) ? _objectSpread(_objectSpread({}, other), {}, {
    version
  }) : {}), {}, {
    color: item.props.color !== undefined ? item.props.color : ['onesy-NavigationItem'].includes(item.type?.displayName) ? color : styles.icon.color,
    tonal: item.props.tonal !== undefined ? item.props.tonal : tonal,
    selected: selected.includes(item.props.value),
    onClick: () => {
      if (!item.props.disabled) {
        onSelect(item.props);

        // Invoke items on click method
        if (is('function', item.props.onClick)) item.props.onClick();
      }
    }
  })));
  return /*#__PURE__*/React.createElement(Surface, _extends({
    ref: ref,
    Component: Line,
    color: color,
    tonal: tonal,
    direction: "row",
    align: "center",
    justify: "initial",
    gap: 1,
    className: classNames([staticClassName('NavigationBar', theme) && ['onesy-NavigationBar-root'], className, classes.root, fixed && classes.fixed]),
    style: _objectSpread(_objectSpread({}, style), styles.root)
  }, other), children);
});
NavigationBar.displayName = 'onesy-NavigationBar';
export default NavigationBar;

==> ui-react-1.1.440.tgz: package/esm/NavigationBar/NavigationBar.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["color", "tonal", "version", "value", "valueDefault", "onChange", "fixed", "className", "style", "children"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { is } from '@amaui/utils';
import { classNames, style as styleMethod, useAmauiTheme } from '@amaui/style-react';
import LineElement from '../Line';
import SurfaceElement from '../Surface';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {
    zIndex: theme.z_index.app_bar,
    width: '100%',
    padding: '0'
  },
  fixed: {
    position: 'fixed',
    insetInline: '0',
    bottom: '0'
  }
}), {
  name: 'amaui-NavigationBar'
});
const NavigationBar = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiNavigationBar?.props?.default), props_), [props_]);
  const Line = React.useMemo(() => theme?.elements?.Line || LineElement, [theme]);
  const Surface = React.useMemo(() => theme?.elements?.Surface || SurfaceElement, [theme]);
  const {
      color = 'primary',
      tonal = true,
      version = 'regular',
      value,
      valueDefault,
      onChange,
      fixed,
      className,
      style,
      children: children_
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const [init, setInit] = React.useState(false);
  const [selected, setSelected] = React.useState(() => {
    const valueNew = valueDefault !== undefined ? valueDefault : value;
    return valueNew !== undefined ? is('array', valueNew) ? valueNew : [valueNew] : [];
  });
  const styles = {
    root: {},
    icon: {}
  };
  React.useEffect(() => {
    setInit(true);
  }, []);
  React.useEffect(() => {
    if (init && value !== selected) setSelected(is('array', value) ? value : [value]);
  }, [value]);
  const onSelect = itemProps => {
    // Only one item at the time is selectable,
    // and it cannot be unselected by clicking on the same item
    const valueNew = [itemProps.value];
    if (valueNew !== undefined) {
      // Update inner or controlled
      if (!props.hasOwnProperty('value')) setSelected(valueNew);
      if (is('function', onChange)) onChange(valueNew);
    }
  };
  let palette;
  if (!theme.palette.color[color] && !['themed', 'inverted', 'default', 'inherit'].includes(color)) {
    palette = theme.methods.color(color);
  }
  if (!theme.palette.color[color] && !['themed', 'inverted', 'default', 'inherit'].includes(color)) {
    if (tonal) styles.root.backgroundColor = theme.methods.palette.color.value(undefined, 95, true, palette);else styles.root.backgroundColor = palette.main;
  }
  if (!tonal) {
    let background = theme.palette.color[color]?.main;
    if (color === 'default') background = theme.palette.background.default.primary;
    styles.icon.color = theme.methods.palette.color.text(palette?.main || background, true, 'light');
  } else {
    styles.icon.color = theme.methods.palette.color.value(color, 5, true, palette);
  }
  const children = React.Children.toArray(children_).map((item, index) => /*#__PURE__*/React.cloneElement(item, _objectSpread(_objectSpread({
    key: index
  }, ['amaui-NavigationItem'].includes(item.type?.displayName) ? _objectSpread(_objectSpread({}, other), {}, {
    version
  }) : {}), {}, {
    color: item.props.color !== undefined ? item.props.color : ['amaui-NavigationItem'].includes(item.type?.displayName) ? color : styles.icon.color,
    tonal: item.props.tonal !== undefined ? item.props.tonal : tonal,
    selected: selected.includes(item.props.value),
    onClick: () => {
      if (!item.props.disabled) {
        onSelect(item.props);

        // Invoke items on click method
        if (is('function', item.props.onClick)) item.props.onClick();
      }
    }
  })));
  return /*#__PURE__*/React.createElement(Surface, _extends({
    ref: ref,
    Component: Line,
    color: color,
    tonal: tonal,
    direction: "row",
    align: "center",
    justify: "initial",
    gap: 1,
    className: classNames([staticClassName('NavigationBar', theme) && ['amaui-NavigationBar-root'], className, classes.root, fixed && classes.fixed]),
    style: _objectSpread(_objectSpread({}, style), styles.root)
  }, other), children);
});
NavigationBar.displayName = 'amaui-NavigationBar';
export default NavigationBar;
